@@ -472,22 +472,22 @@ def Newpopulation(population, PopSize): #สำหรับสร้างปร
 
 def u_ga(filename):
     Cycle_time = float(input("Enter the cycle time : ")) #ใส่รอบเวลา
-    PopSize = input("Enter the population size : ") #ใส่จำนวนประชากร
+    PopSize = input("Enter the population size(Default = 30) : ") #ใส่จำนวนประชากร
     if PopSize == "d": #ถ้าใส่ d ค่า PopSize จะถูกกำหนดให้เท่ากับ 20
         PopSize = 30
     else :
         PopSize = int(PopSize)
-    Crossover_rate = input("Enter the crossover rate : ") #ใส่ Crossover_rate
+    Crossover_rate = input("Enter the crossover rate(Default = 0.7) : ") #ใส่ Crossover_rate
     if Crossover_rate == "d": #ถ้าใส่ d ค่า Crossover_rate จะถูกกำหนดให้เท่ากับ 0.7
         Crossover_rate = 0.7
     else :
         Crossover_rate = float(Crossover_rate)
-    Mutation_rate = input("Enter the mutation rate : ") #ใส่ Mutation_rate
+    Mutation_rate = input("Enter the mutation rate(Default = 0.3) : ") #ใส่ Mutation_rate
     if Mutation_rate == "d": #ถ้าใส่ d ค่า Mutation_rate จะถูกกำหนดให้เท่ากับ 0.3
         Mutation_rate = 0.3
     else :
         Mutation_rate = float(Mutation_rate)
-    maxGen = input("Enter the max generation : ") #ใส่จำนวนรุ่นสูงสุด
+    maxGen = input("Enter the max generation(Default = 100) : ") #ใส่จำนวนรุ่นสูงสุด
     if maxGen == "d": #ถ้าใส่ d ค่า maxGen จะถูกกำหนดให้เท่ากับ 100
         maxGen = 100
     else :
@@ -529,7 +529,7 @@ def u_ga(filename):
             
         BestofFit = BestFit(filename, population, Crossover_population, Mutation_population, Cycle_time, init_eff, init_sm, PopSize)
         BestofFitness = BestofFit[0][0] #เก็บค่า fitness ที่น้อยที่สุด
-        
+        print(q, '%.2f' %(BestofFitness)) #แสดงค่า Fitness ที่ดีที่สุดในแต่ละรุ่น
         bestFitnessList.append(BestofFitness) #นำค่า fitness ที่น้อยที่สุดของประชากรทุกรุ่นไปไว้ใน bestFitnessList
         # ถ้าค่า BestofFitness น้อยกว่าค่า fitness ที่น้อยที่สุดเดิม จะเปลี่ยนค่า bestFitness เป็นค่า BestofFitness แทน
         if BestofFitness < bestFitness: 
@@ -546,22 +546,22 @@ def u_ga(filename):
 
 def parallel_ga(filename):
     Cycle_time = float(input("Enter the cycle time : "))
-    PopSize = input("Enter the population size : ") #ใส่จำนวนประชากร
+    PopSize = input("Enter the population size(Default = 30) : ") #ใส่จำนวนประชากร
     if PopSize == "d": #ถ้าใส่ d ค่า PopSize จะถูกกำหนดให้เท่ากับ 20
         PopSize = 30
     else :
         PopSize = int(PopSize)
-    Crossover_rate = input("Enter the crossover rate : ") #ใส่ Crossover_rate
+    Crossover_rate = input("Enter the crossover rate(Default = 0.7) : ") #ใส่ Crossover_rate
     if Crossover_rate == "d": #ถ้าใส่ d ค่า Crossover_rate จะถูกกำหนดให้เท่ากับ 0.7
         Crossover_rate = 0.7
     else :
         Crossover_rate = float(Crossover_rate)
-    Mutation_rate = input("Enter the mutation rate : ") #ใส่ Mutation_rate
+    Mutation_rate = input("Enter the mutation rate(Default = 0.3) : ") #ใส่ Mutation_rate
     if Mutation_rate == "d": #ถ้าใส่ d ค่า Mutation_rate จะถูกกำหนดให้เท่ากับ 0.3
         Mutation_rate = 0.3
     else :
         Mutation_rate = float(Mutation_rate)
-    maxGen = input("Enter the max generation : ") #ใส่จำนวนรุ่นสูงสุด
+    maxGen = input("Enter the max generation(Default = 100) : ") #ใส่จำนวนรุ่นสูงสุด
     if maxGen == "d": #ถ้าใส่ d ค่า maxGen จะถูกกำหนดให้เท่ากับ 100
         maxGen = 100
     else :
@@ -604,7 +604,7 @@ def parallel_ga(filename):
         # list ที่จัดเรียงค่า fitness แล้ว    
         BestofFit = BestFit_Pa(filename, population, Crossover_population, Mutation_population, Cycle_time, init_eff, init_sm, PopSize)
         BestofFitness = BestofFit[0][0] #เก็บค่า fitness ที่น้อยที่สุด
-        
+        print(q, '%.2f' %(BestofFitness)) #แสดงค่า Fitness ที่ดีที่สุดในแต่ละรุ่น
         bestFitnessList.append(BestofFitness) #นำค่า fitness ที่น้อยที่สุดของประชากรทุกรุ่นไปไว้ใน bestFitnessList
         # ถ้าค่า BestofFitness น้อยกว่าค่า fitness ที่น้อยที่สุดเดิม จะเปลี่ยนค่า bestFitness เป็นค่า BestofFitness แทน
         if BestofFitness < bestFitness:
